.. _developer_api:

Developer API
=============

This is the class and function reference of pvfactors.
For clarity and simplicity, all inherited methods and attributes have been removed from the class descriptions as there were often too many irrelevant ones coming from base packages like shapely.

.. include:: geometry.rst

.. include:: viewfactors.rst

.. include:: irradiance.rst

.. include:: engine.rst

.. include:: run.rst

.. include:: report.rst
